@@ -1,6 +1,6 @@
 package Dancer2::Core::Role::SessionFactory;
 {
-  $Dancer2::Core::Role::SessionFactory::VERSION = '0.02';
+  $Dancer2::Core::Role::SessionFactory::VERSION = '0.03';
 }
 
 #ABSTRACT: Role for session factories
@@ -102,6 +102,7 @@ sub create {
 
     $self->execute_hook('engine.session.before_create', $session);
 
+    # XXX why do we _flush now?  Seems unnecessary -- xdg, 2013-03-03
     eval { $self->_flush($session->id, $session->data) };
     croak "Unable to create a new session: $@"
       if $@;
@@ -112,10 +113,9 @@ sub create {
 
 
 {
-    my $COUNTER = 0;
-    my $CPRNG_AVAIL =
-        Dancer2::ModuleLoader->require("Math::Random::ISAAC::XS") &&
-        Dancer2::ModuleLoader->require("Crypt::URandom");
+    my $COUNTER     = 0;
+    my $CPRNG_AVAIL = Dancer2::ModuleLoader->require("Math::Random::ISAAC::XS")
+      && Dancer2::ModuleLoader->require("Crypt::URandom");
 
     # don't initialize until generate_id is called so the ISAAC algorithm
     # is seeded after any pre-forking
@@ -125,25 +125,29 @@ sub create {
     sub generate_id {
         my ($self) = @_;
 
-        if ( $CPRNG_AVAIL ) {
+        if ($CPRNG_AVAIL) {
             $CPRNG ||= Math::Random::ISAAC::XS->new(
-                map { unpack("N", Crypt::URandom::urandom(4)) } 1 .. 256
-            );
+                map { unpack("N", Crypt::URandom::urandom(4)) } 1 .. 256);
+
             # include $$ to ensure $CPRNG wasn't forked by accident
             return encode_base64url(
-                pack("N6", time, $$, $CPRNG->irand, $CPRNG->irand, $CPRNG->irand, $CPRNG->irand)
+                pack("N6",
+                    time,          $$,            $CPRNG->irand,
+                    $CPRNG->irand, $CPRNG->irand, $CPRNG->irand)
             );
         }
         else {
-            my $seed = (rand(1_000_000_000)    # a random number
-              . __FILE__                    # the absolute path as a secret key
-              .  $COUNTER++    # impossible to have two consecutive dups
-              . $$            # the process ID as another private constant
-              . "$self"       # the instance's memory address for more entropy
-              . join('', shuffle('a' .. 'z', 'A' .. 'Z', 0 .. 9))
-                # a shuffled list of 62 chars, another random component
+            my $seed = (
+                rand(1_000_000_000)   # a random number
+                  . __FILE__          # the absolute path as a secret key
+                  . $COUNTER++        # impossible to have two consecutive dups
+                  . $$         # the process ID as another private constant
+                  . "$self"    # the instance's memory address for more entropy
+                  . join('', shuffle('a' .. 'z', 'A' .. 'Z', 0 .. 9))
+
+                  # a shuffled list of 62 chars, another random component
             );
-            return encode_base64url( pack( "Na*", time, sha1($seed) ) );
+            return encode_base64url(pack("Na*", time, sha1($seed)));
         }
 
     }
@@ -266,7 +270,7 @@ Dancer2::Core::Role::SessionFactory - Role for session factories
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 DESCRIPTION
 
@@ -375,6 +379,10 @@ argumenet and destroy the underlying data.
 Make sure the session object is stored in the factory's backend. This method is
 called to notify the backend about the change in the session object.
 
+The Dancer application will not call flush unless the session C<is_dirty>
+attribute is true to avoid unnecessary writes to the database when no
+data has been modified.
+
 An exception is triggered if the session is unable to be updated in the backend.
 
     MySessionFactory->flush(session => $session);
