@@ -2,7 +2,7 @@
 
 package Dancer2::Test;
 {
-  $Dancer2::Test::VERSION = '0.02';
+  $Dancer2::Test::VERSION = '0.03';
 }
 use strict;
 use warnings;
@@ -95,7 +95,7 @@ sub _build_request_from_env {
             push @params,
               uri_escape($p) . '=' . uri_escape($options->{params}->{$p});
         }
-        $env->{REQUEST_URI} = join('&', @params);
+        $env->{QUERY_STRING} = join('&', @params);
     }
 
     my $request = Dancer2::Core::Request->new(env => $env);
@@ -142,7 +142,7 @@ sub _build_env_from_request {
         foreach my $p (keys %{$params}) {
             push @params, uri_escape($p) . '=' . uri_escape($params->{$p});
         }
-        $env->{REQUEST_URI} = join('&', @params);
+        $env->{QUERY_STRING} = join('&', @params);
     }
 
     # TODO files
@@ -405,7 +405,7 @@ Dancer2::Test - Useful routines for testing Dancer2 apps
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 DESCRIPTION
 
